@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2012-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "multipagedialogbase.h"
@@ -106,7 +101,7 @@ MultiPageDialogBase::MultiPageDialogBase(QWidget *parent, bool withDefaultButton
         m_pageDialog->showButtonSeparator(true);
         m_pageDialog->setFaceType(KPageDialog::List);
         m_pageDialog->setModal(true);
-        m_pageDialog->setHelp(QString(), QString::fromLatin1("umbrello"));
+        m_pageDialog->setHelp(QString::fromLatin1("settings"), QString::fromLatin1("umbrello"));
         connect(m_pageDialog, SIGNAL(okClicked()), this, SLOT(slotOkClicked()));
         connect(m_pageDialog, SIGNAL(applyClicked()), this, SLOT(slotApplyClicked()));
         connect(m_pageDialog, SIGNAL(defaultClicked()), this, SLOT(slotDefaultClicked()));
@@ -270,7 +265,7 @@ void MultiPageDialogBase::slotDefaultClicked()
 void MultiPageDialogBase::slotHelpClicked()
 {
     DEBUG(DBG_SRC)  << "HELP clicked...directly handled";
-    KHelpClient::invokeHelp(QLatin1String("help:/umbrello/index.html"), QLatin1String("umbrello"));
+    KHelpClient::invokeHelp(QLatin1String("settings"), QLatin1String("umbrello"));
 }
 
 /**
@@ -488,7 +483,7 @@ KPageWidgetItem *MultiPageDialogBase::setupStylePage(WidgetBase *widget)
 KPageWidgetItem *MultiPageDialogBase::setupStylePage(AssociationWidget *widget)
 {
     m_pStylePage = new UMLWidgetStylePage(0, widget);
-    return createPage(i18nc("style page name", "Style"), i18n("Role Style"),
+    return createPage(i18nc("style page name", "Style"), i18n("Line Style"),
                       Icon_Utils::it_Properties_Color, m_pStylePage);
 }
 
