@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2012-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // self includes
 #include "dotgenerator.h"
@@ -40,6 +35,12 @@
 #include <QTemporaryFile>
 #include <QTextStream>
 
+QString dotType(WidgetBase *widget)
+{
+    const QString rawType = widget->baseTypeStr();
+    return rawType.toLower().remove(QLatin1String("wt_"));
+}
+
 /**
  * dot specific paint engine
  */
@@ -58,7 +59,7 @@ public:
     virtual void drawImage(const QRectF & rectangle, const QImage & image, const QRectF & sr, Qt::ImageConversionFlags flags = Qt::AutoColor) { Q_UNUSED(rectangle) Q_UNUSED(image) Q_UNUSED(sr) Q_UNUSED(flags) }
     virtual void drawLines(const QLineF * lines, int lineCount) { Q_UNUSED(lines) Q_UNUSED(lineCount) }
     virtual void drawLines(const QLine * lines, int lineCount) { Q_UNUSED(lines) Q_UNUSED(lineCount) }
-    virtual void drawwPath(const QPainterPath & path) { Q_UNUSED(path) }
+    virtual void drawPath(const QPainterPath & path) { Q_UNUSED(path) }
     virtual void drawPixmap(const QRectF & r, const QPixmap & pm, const QRectF & sr) { Q_UNUSED(r) Q_UNUSED(pm) Q_UNUSED(sr) }
     virtual void drawPoints(const QPointF * points, int pointCount) { Q_UNUSED(points) Q_UNUSED(pointCount) }
     virtual void drawPoints(const QPoint * points, int pointCount) { Q_UNUSED(points) Q_UNUSED(pointCount) }
@@ -136,6 +137,58 @@ DotGenerator::DotGenerator()
     m_usePosition(false),
     m_useFullNodeLabels(true)
 {
+    Settings::OptionState& optionState = Settings::optionState();
+    if (optionState.autoLayoutState.autoDotPath) {
+        m_dotPath = currentDotPath();
+    }
+    else if (!optionState.autoLayoutState.dotPath.isEmpty()) {
+        m_dotPath = optionState.autoLayoutState.dotPath;
+    }
+}
+
+/**
+ * Return the path where dot is installed.
+ *
+ * @return string with dot path
+ */
+QString DotGenerator::currentDotPath()
+{
+#if QT_VERSION >= 0x050000
+    QString executable = QStandardPaths::findExecutable(QLatin1String("dot"));
+#else
+    QString executable = KStandardDirs::findExe(QLatin1String("dot"));
+#endif
+    if (!executable.isEmpty()) {
+        QFileInfo fi(executable);
+        return fi.absolutePath();
+    }
+#ifdef Q_OS_WIN
+    // search for dot installation
+    QString appDir(QLatin1String(qgetenv("ProgramFiles").constData()));
+    QDir dir(appDir);
+    dir.setFilter(QDir::Dirs);
+    dir.setNameFilters(QStringList() << QLatin1String("Graphviz*"));
+    dir.setSorting(QDir::Reversed);
+    QFileInfoList list = dir.entryInfoList();
+    if (list.size() > 0) {
+        QString dotPath = list.at(0).absoluteFilePath();
+        QString exePath = QFile::exists(dotPath + QLatin1String("\\bin")) ? dotPath + QLatin1String("\\bin") : dotPath;
+        return QFile::exists(exePath + QLatin1String("\\dot.exe")) ? exePath : QString();
+    }
+#endif
+    return QString();
+}
+
+void DotGenerator::setGeneratorName(const QString &name)
+{
+    m_generator = name;
+    m_version = generatorVersion();
+    uDebug() << "found graphviz generator at " << generatorFullPath() << " with version " << m_version;
+}
+
+QString DotGenerator::generatorFullPath()
+{
+    return m_dotPath + QLatin1Char('/') + m_generator;
 }
 
 /**
@@ -191,7 +244,7 @@ bool DotGenerator::availableConfigFiles(UMLScene *scene, QHash<QString, QString>
 {
     QString diagramType = Uml::DiagramType::toString(scene->type()).toLower();
 #if QT_VERSION >= 0x050000
-    QStringList fileNames = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QString::fromLatin1("umbrello/layouts/%1*.desktop").arg(diagramType));
+    QStringList fileNames = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QString::fromLatin1("umbrello5/layouts/%1*.desktop").arg(diagramType));
 #else
     KStandardDirs dirs;
 
@@ -215,8 +268,8 @@ bool DotGenerator::availableConfigFiles(UMLScene *scene, QHash<QString, QString>
 /**
  * Read a layout config file
  *
- * @param diagramType String identifing the diagram
- * @param variant String identifing the variant
+ * @param diagramType String identifying the diagram
+ * @param variant String identifying the variant
  * @return true on success
  */
 bool DotGenerator::readConfigFile(QString diagramType, const QString &variant)
@@ -231,7 +284,7 @@ bool DotGenerator::readConfigFile(QString diagramType, const QString &variant)
     QString configFileName;
     foreach(const QString &fileName, fileNames) {
 #if QT_VERSION >= 0x050000
-        configFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QString::fromLatin1("umbrello/layouts/%1").arg(fileName));
+        configFileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QString::fromLatin1("umbrello5/layouts/%1").arg(fileName));
 #else
         configFileName = KStandardDirs::locate("data", QString::fromLatin1("umbrello/layouts/%1").arg(fileName));
 #endif
@@ -249,6 +302,8 @@ bool DotGenerator::readConfigFile(QString diagramType, const QString &variant)
     KConfigGroup edgesAttributes(&desktopFile,"X-UMBRELLO-Dot-Edges");
     KConfigGroup nodesAttributes(&desktopFile,"X-UMBRELLO-Dot-Nodes");
     KConfigGroup attributes(&desktopFile,"X-UMBRELLO-Dot-Attributes");
+    QString layoutType = Uml::LayoutType::toString(Settings::optionState().generalState.layoutType);
+    KConfigGroup layoutAttributes(&desktopFile,QString(QLatin1String("X-UMBRELLO-Dot-Attributes-%1")).arg(layoutType));
     // settings are not needed by dotgenerator
     KConfigGroup settings(&desktopFile,"X-UMBRELLO-Dot-Settings");
 
@@ -262,6 +317,16 @@ bool DotGenerator::readConfigFile(QString diagramType, const QString &variant)
             m_dotParameters[key] = value;
     }
 
+    foreach(const QString &key, layoutAttributes.keyList()) {
+        QString value = layoutAttributes.readEntry(key);
+        if (!value.isEmpty()) {
+            if (!m_dotParameters.contains(key))
+                m_dotParameters[key] = value;
+            else
+                m_dotParameters[key].append(QLatin1String(",") + value);
+        }
+    }
+
     foreach(const QString &key, nodesAttributes.keyList()) {
         QString value = nodesAttributes.readEntry(key);
         m_nodeParameters[key] = value;
@@ -283,7 +348,7 @@ bool DotGenerator::readConfigFile(QString diagramType, const QString &variant)
     else
         uError() << "illegal format of entry 'origin'" << value;
 
-    m_generator = settings.readEntry("generator", "dot");
+    setGeneratorName(settings.readEntry("generator", "dot"));
 
 #ifdef LAYOUTGENERATOR_DATA_DEBUG
     uDebug() << m_edgeParameters;
@@ -326,8 +391,7 @@ bool DotGenerator::createDotFile(UMLScene *scene, const QString &fileName, const
         if (usePosition())
             params  << QString::fromLatin1("pos=\"%1, %2\"").arg(widget->x()+widget->width()/2).arg(widget->y()+widget->height()/2);
 
-        const QString rawType = widget->baseTypeStr();
-        QString type = rawType.toLower().remove(QLatin1String("wt_"));
+        QString type = dotType(widget);
 
         if (type == QLatin1String("state")) {
             StateWidget *w = static_cast<StateWidget *>(widget);
@@ -382,6 +446,28 @@ bool DotGenerator::createDotFile(UMLScene *scene, const QString &fileName, const
         if (!widget->isTextWidget())
             out << "\"" << id << "\""
                 << " [" << params.join(QLatin1String(",")) << "];\n";
+        // add associations for child items
+        foreach(QGraphicsItem *item, widget->childItems()) {
+            UMLWidget *w2 = dynamic_cast<UMLWidget *>(item);
+            QString type2 = dotType(w2);
+            QString id2 = fixID(Uml::ID::toString(w2->localID()));
+            QStringList params2;
+            QString vkey = QString(QLatin1String("visual::type::%1::%2")).arg(type).arg(type2);
+            if (m_edgeParameters.contains(vkey)) {
+                params2 << m_edgeParameters[vkey];
+            } else {
+                uDebug() << "key" << vkey << "not found; skipping association";
+                continue;
+            }
+            vkey = QString(QLatin1String("ranking::type::%1::%2")).arg(type).arg(type2);
+            if (m_edgeParameters.contains(vkey)) {
+                params2 << m_edgeParameters[vkey];
+            } else {
+                uDebug() << "key" << vkey << "not found";
+            }
+            out << "\"" << id << "\" -> \"" << id2 << "\""
+                << " [" << params2.join(QLatin1String(",")) << "];\n";
+        }
     }
 
     foreach(AssociationWidget *assoc, scene->associationList()) {
@@ -487,6 +573,23 @@ QString DotGenerator::fixID(const QString &_id)
     return id;
 }
 
+/**
+ * get generator version
+ * @return version for example 20130928
+ */
+int DotGenerator::generatorVersion()
+{
+    QProcess p;
+    QStringList args;
+    args << QLatin1String("-V");
+    p.start(generatorFullPath(), args);
+    p.waitForFinished();
+    QString out(QLatin1String(p.readAllStandardError()));
+    QRegExp rx(QLatin1String("\\((.*)\\."));
+    QString version = rx.indexIn(out) != -1 ? rx.cap(1) : QString();
+    return version.toInt(0);
+}
+
 #if 0
 static QDebug operator<<(QDebug out, LayoutGenerator &c)
 {
